==> haskell-yesod-core-1.6.14-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.14
id: yesod-core-1.6.14-JgtSTP4YcgE3FYyZqk66am
key: yesod-core-1.6.14-JgtSTP4YcgE3FYyZqk66am
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: 8bc863b3626c57f3af49da595ec8a90e
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-core-1.6.14
hs-libraries: HSyesod-core-1.6.14-JgtSTP4YcgE3FYyZqk66am
depends:
    aeson-1.4.2.0-4xcoKSM2rCuFeYBdCYWLDU
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    clientsession-0.9.1.2-38NHrIsylOx2AXJejwSg9m
    conduit-1.3.1.1-IQr01ehJbIbFHxZqbcjBvx
    conduit-extra-1.3.1.1-9AIEqqUHeTdBpIhmz3EoB8 containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    fast-logger-2.4.15-1nBSFCOZiNwHPgWMlH3CM3
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-logger-0.3.30-925Jm0DLIIrLZBfvMH3OJJ mtl-2.2.2
    parsec-3.1.13.0 path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t
    rio-0.1.9.2-Jrb8lXKJqCGJ0ZBENk2SPb
    shakespeare-2.0.20-D4kKkLN1PySIaMayVrQDBO template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unliftio-0.2.10-5CtrP9qLpzqL8L0y8iRtf0
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    wai-3.2.2-GrHvuMWBg0KAzl6COLfHLZ
    wai-extra-3.0.25-9C75jqkXOQZ8OqSrgBEOK1
    wai-logger-2.3.4-I62eIKyj72NEACiVBIEGIs
    warp-3.2.26-1qSsM6Mo0XC2AlUzITQieW
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.14-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.14
id: yesod-core-1.6.14-HLJTT0Yn5IP6V5ktWj9g5I
key: yesod-core-1.6.14-HLJTT0Yn5IP6V5ktWj9g5I
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: e12302d10388ffc44a00a250a365c634
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-core-1.6.14
hs-libraries: HSyesod-core-1.6.14-HLJTT0Yn5IP6V5ktWj9g5I
depends:
    aeson-1.4.2.0-4xcoKSM2rCuFeYBdCYWLDU
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    clientsession-0.9.1.2-38NHrIsylOx2AXJejwSg9m
    conduit-1.3.1.1-Jqkrz3R953b3ZlpJd9iBNU
    conduit-extra-1.3.1.1-2QYMOmJ0m8KyiTrN1ufER containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    fast-logger-2.4.15-1nBSFCOZiNwHPgWMlH3CM3
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-logger-0.3.30-C8EtnoCUtGhAuuCpMbuXUt mtl-2.2.2
    parsec-3.1.13.0 path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t
    rio-0.1.9.2-Jrb8lXKJqCGJ0ZBENk2SPb
    shakespeare-2.0.20-D4kKkLN1PySIaMayVrQDBO template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unliftio-0.2.10-5CtrP9qLpzqL8L0y8iRtf0
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    wai-3.2.2-GrHvuMWBg0KAzl6COLfHLZ
    wai-extra-3.0.25-9C75jqkXOQZ8OqSrgBEOK1
    wai-logger-2.3.4-I62eIKyj72NEACiVBIEGIs
    warp-3.2.26-Davajzloe8lHEINju9SeZO
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
